==> prison-5.105.0-1-aarch64.pkg.tar.xz: usr/include/KF5/PrisonScanner/Prison/prisonscanner_export.h <==

#ifndef PRISONSCANNER_EXPORT_H
#define PRISONSCANNER_EXPORT_H

#ifdef PRISONSCANNER_STATIC_DEFINE
#  define PRISONSCANNER_EXPORT
#  define PRISONSCANNER_NO_EXPORT
#else
#  ifndef PRISONSCANNER_EXPORT
#    ifdef KF5PrisonScanner_EXPORTS
        /* We are building this library */
#      define PRISONSCANNER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PRISONSCANNER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PRISONSCANNER_NO_EXPORT
#    define PRISONSCANNER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PRISONSCANNER_DECL_DEPRECATED
#  define PRISONSCANNER_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PRISONSCANNER_DECL_DEPRECATED_EXPORT
#  define PRISONSCANNER_DECL_DEPRECATED_EXPORT PRISONSCANNER_EXPORT PRISONSCANNER_DECL_DEPRECATED
#endif

#ifndef PRISONSCANNER_DECL_DEPRECATED_NO_EXPORT
#  define PRISONSCANNER_DECL_DEPRECATED_NO_EXPORT PRISONSCANNER_NO_EXPORT PRISONSCANNER_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PRISONSCANNER_NO_DEPRECATED
#    define PRISONSCANNER_NO_DEPRECATED
#  endif
#endif

#define PRISONSCANNER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))

/* Take any defaults from group settings */
#if !defined(PRISONSCANNER_NO_DEPRECATED) && !defined(PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define PRISONSCANNER_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(PRISONSCANNER_NO_DEPRECATED_WARNINGS) && !defined(PRISONSCANNER_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define PRISONSCANNER_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(PRISONSCANNER_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(PRISONSCANNER_NO_DEPRECATED)
#  undef PRISONSCANNER_DEPRECATED
#  define PRISONSCANNER_DEPRECATED_EXPORT PRISONSCANNER_EXPORT
#  define PRISONSCANNER_DEPRECATED_NO_EXPORT PRISONSCANNER_NO_EXPORT
#elif defined(PRISONSCANNER_NO_DEPRECATED_WARNINGS)
#  define PRISONSCANNER_DEPRECATED
#  define PRISONSCANNER_DEPRECATED_EXPORT PRISONSCANNER_EXPORT
#  define PRISONSCANNER_DEPRECATED_NO_EXPORT PRISONSCANNER_NO_EXPORT
#else
#  define PRISONSCANNER_DEPRECATED PRISONSCANNER_DECL_DEPRECATED
#  define PRISONSCANNER_DEPRECATED_EXPORT PRISONSCANNER_DECL_DEPRECATED_EXPORT
#  define PRISONSCANNER_DEPRECATED_NO_EXPORT PRISONSCANNER_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PRISONSCANNER_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PRISONSCANNER_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PRISONSCANNER_NO_DEPRECATED
#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56900
#endif
#ifdef PRISONSCANNER_NO_DEPRECATED_WARNINGS
#  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PRISONSCANNER_DEPRECATED_WARNINGS_SINCE
#  ifdef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x56900
#  endif
#endif

#ifndef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
#endif

#ifdef PRISONSCANNER_DEPRECATED
#  define PRISONSCANNER_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PRISONSCANNER_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* PRISONSCANNER_EXPORT_H */

==> prison-5.106.0-1-aarch64.pkg.tar.xz: usr/include/KF5/PrisonScanner/Prison/prisonscanner_export.h <==

#ifndef PRISONSCANNER_EXPORT_H
#define PRISONSCANNER_EXPORT_H

#ifdef PRISONSCANNER_STATIC_DEFINE
#  define PRISONSCANNER_EXPORT
#  define PRISONSCANNER_NO_EXPORT
#else
#  ifndef PRISONSCANNER_EXPORT
#    ifdef KF5PrisonScanner_EXPORTS
        /* We are building this library */
#      define PRISONSCANNER_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define PRISONSCANNER_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef PRISONSCANNER_NO_EXPORT
#    define PRISONSCANNER_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef PRISONSCANNER_DECL_DEPRECATED
#  define PRISONSCANNER_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef PRISONSCANNER_DECL_DEPRECATED_EXPORT
#  define PRISONSCANNER_DECL_DEPRECATED_EXPORT PRISONSCANNER_EXPORT PRISONSCANNER_DECL_DEPRECATED
#endif

#ifndef PRISONSCANNER_DECL_DEPRECATED_NO_EXPORT
#  define PRISONSCANNER_DECL_DEPRECATED_NO_EXPORT PRISONSCANNER_NO_EXPORT PRISONSCANNER_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef PRISONSCANNER_NO_DEPRECATED
#    define PRISONSCANNER_NO_DEPRECATED
#  endif
#endif

#define PRISONSCANNER_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(PRISONSCANNER_NO_DEPRECATED) && !defined(PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define PRISONSCANNER_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(PRISONSCANNER_NO_DEPRECATED_WARNINGS) && !defined(PRISONSCANNER_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define PRISONSCANNER_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(PRISONSCANNER_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(PRISONSCANNER_NO_DEPRECATED)
#  undef PRISONSCANNER_DEPRECATED
#  define PRISONSCANNER_DEPRECATED_EXPORT PRISONSCANNER_EXPORT
#  define PRISONSCANNER_DEPRECATED_NO_EXPORT PRISONSCANNER_NO_EXPORT
#elif defined(PRISONSCANNER_NO_DEPRECATED_WARNINGS)
#  define PRISONSCANNER_DEPRECATED
#  define PRISONSCANNER_DEPRECATED_EXPORT PRISONSCANNER_EXPORT
#  define PRISONSCANNER_DEPRECATED_NO_EXPORT PRISONSCANNER_NO_EXPORT
#else
#  define PRISONSCANNER_DEPRECATED PRISONSCANNER_DECL_DEPRECATED
#  define PRISONSCANNER_DEPRECATED_EXPORT PRISONSCANNER_DECL_DEPRECATED_EXPORT
#  define PRISONSCANNER_DEPRECATED_NO_EXPORT PRISONSCANNER_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define PRISONSCANNER_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define PRISONSCANNER_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef PRISONSCANNER_NO_DEPRECATED
#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
#endif
#ifdef PRISONSCANNER_NO_DEPRECATED_WARNINGS
#  define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef PRISONSCANNER_DEPRECATED_WARNINGS_SINCE
#  ifdef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define PRISONSCANNER_DEPRECATED_WARNINGS_SINCE 0x56a00
#  endif
#endif

#ifndef PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
#endif

#ifdef PRISONSCANNER_DEPRECATED
#  define PRISONSCANNER_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > PRISONSCANNER_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define PRISONSCANNER_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* PRISONSCANNER_EXPORT_H */
